==> winnie-0.1.46.tgz: package/serial/model-to-code.js <==
'use strict';

var _toConsumableArray = require('@babel/runtime/helpers/toConsumableArray');
var _slicedToArray = require('@babel/runtime/helpers/slicedToArray');
var _classCallCheck = require('@babel/runtime/helpers/classCallCheck');
var _createClass = require('@babel/runtime/helpers/createClass');
var GridPane = require('kenga-containers/grid-pane');
var ColumnNode = require('kenga-grid/columns/column-node');
var Widget = require('kenga/widget');
require('./serials.js');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var _toConsumableArray__default = /*#__PURE__*/_interopDefaultLegacy(_toConsumableArray);
var _slicedToArray__default = /*#__PURE__*/_interopDefaultLegacy(_slicedToArray);
var _classCallCheck__default = /*#__PURE__*/_interopDefaultLegacy(_classCallCheck);
var _createClass__default = /*#__PURE__*/_interopDefaultLegacy(_createClass);
var GridPane__default = /*#__PURE__*/_interopDefaultLegacy(GridPane);
var ColumnNode__default = /*#__PURE__*/_interopDefaultLegacy(ColumnNode);
var Widget__default = /*#__PURE__*/_interopDefaultLegacy(Widget);

function concat(prev, item) {
  if (!!prev && !!item) return "".concat(prev, "\n").concat(item);else if (!!prev) return prev;else return item;
}

function decapitalize(name) {
  return name.substring(0, 1).toLowerCase() + name.substring(1);
}

function capitalize(name) {
  return name.split('-').map(function (item) {
    return item.substring(0, 1).toUpperCase() + item.substring(1);
  }).join('');
}

function lastSlashTail(name) {
  var lsi = name.lastIndexOf('/');

  if (lsi > -1) {
    return name.substring(lsi + 1, name.length);
  } else {
    return name;
  }
}

function nvl(placeholder, name) {
  return name ? name : placeholder;
}

var Es6Generator = /*#__PURE__*/function () {
  function Es6Generator(model) {
    _classCallCheck__default['default'](this, Es6Generator);

    this.model = model;
    this.consts = new Set();
    this.fromToLocalConstructor = new Map(); // item.from -> local constructor name

    this.widgetToConstName = new Map(); // widget name -> program 'const' name
  }

  _createClass__default['default'](Es6Generator, [{
    key: "generateConstName",
    value: function generateConstName(base) {
      var localConstName = base;
      var nameAttempt = 1;

      while (this.consts.has(localConstName)) {
        localConstName = "".concat(base).concat(nameAttempt++);
      }

      this.consts.add(localConstName);
      return localConstName;
    }
  }, {
    key: "constructorNameOf",
    value: function constructorNameOf(item) {
      if (this.fromToLocalConstructor.has(item.from)) {
        return this.fromToLocalConstructor.get(item.from);
      } else {
        var base = nvl('W', capitalize(lastSlashTail(item.from)).replace(/[^a-z0-9_]/gi, ''));
        var constructorLocalName = this.generateConstName(base);
        this.fromToLocalConstructor.set(item.from, constructorLocalName);
        return constructorLocalName;
      }
    }
  }, {
    key: "constNameOf",
    value: function constNameOf(widgetName) {
      if (this.widgetToConstName.has(widgetName)) {
        return this.widgetToConstName.get(widgetName);
      } else {
        var base = decapitalize(widgetName);
        var constName = this.generateConstName(base);
        this.widgetToConstName.set(widgetName, constName);
        return constName;
      }
    }
  }, {
    key: "imports",
    value: function imports() {
      var _this = this;

      var importsContent = Array.from(new Set(Array.from(this.model.widgets.values()).sort(function (item1, item2) {
        return item1.source.from < item2.source.from ? -1 : item1.source.from > item2.source.from ? 1 : 0;
      }).map(function (item) {
        return "import ".concat(_this.constructorNameOf(item.source), " from '").concat(item.source.from, "';");
      }))).reduce(concat);
      return !!importsContent ? "".concat(importsContent, "\n") : '';
    }
  }, {
    key: "instances",
    value: function instances(indent) {
      var _this2 = this;

      return Array.from(this.model.widgets.entries()).map(function (_ref) {
        var _ref2 = _slicedToArray__default['default'](_ref, 2),
            key = _ref2[0],
            item = _ref2[1];

        var widgetConstName = _this2.constNameOf(key);

        return [item.delegate instanceof GridPane__default['default'] ? "".concat(indent, "const ").concat(widgetConstName, " = new ").concat(_this2.constructorNameOf(item.source), "(").concat(item.delegate.rows, ", ").concat(item.delegate.columns, ");") : "".concat(indent, "const ").concat(widgetConstName, " = new ").concat(_this2.constructorNameOf(item.source), "();"), "".concat(indent, "this.").concat(widgetConstName, " = ").concat(widgetConstName, ";")].reduce(concat);
      }).reduce(concat, '');
    }
  }, {
    key: "forest",
    value: function forest(indent) {
      var _this3 = this;

      var queue = [];
      this.model.forest.forEach(function (item) {
        queue.push.apply(queue, _toConsumableArray__default['default'](item.children));
      });

      for (var i = 0; i < queue.length; i++) {
        queue.push.apply(queue, _toConsumableArray__default['default'](queue[i].children));
      }

      return queue.map(function (item) {
        return "".concat(indent).concat(_this3.constNameOf(item.parent.name), ".").concat(item.delegate instanceof ColumnNode__default['default'] ? 'addColumnNode' : 'add', "(").concat(_this3.constNameOf(item.name), ");");
      }).reduce(concat, '');
    }
  }, {
    key: "sheets",
    value: function sheets(indent) {
      var _this4 = this;

      return Array.from(this.model.widgets.entries()).map(function (_ref3) {
        var _ref4 = _slicedToArray__default['default'](_ref3, 2),
            key = _ref4[0],
            item = _ref4[1];

        var widgetConstName = _this4.constNameOf(key);

        var props = item.sheet.filter(function (p) {
          return p.edited && (!(item.delegate instanceof GridPane__default['default']) || p.name !== 'rows' && p.name !== 'columns');
        }).map(function (p) {
          var assignment = "".concat(indent, "    ").concat(widgetConstName, ".").concat(p.name, " = ").concat(typeof p.value === 'string' ? "'".concat(p.value, "'") : p.value && p.value.src && p.value.getAttribute ? "'".concat(p.value.getAttribute('src'), "'") : p.value, ";");

          if (item.delegate instanceof Widget__default['default'] && p.name === 'classes' && p.value) {
            assignment += "\n".concat(indent, "    ").concat(widgetConstName, ".element.className += ' ' + ").concat(widgetConstName, ".").concat(p.name, ";");
          }

          return assignment;
        }).reduce(concat, '');
        return !!props ? ["".concat(indent, "{"), props, "".concat(indent, "}")].reduce(concat) : '';
      }).reduce(concat, '');
    }
  }, {
    key: "assemble",
    value: function assemble() {
      var generatedName = 'KengaView';
      var indent8 = '        ';
      return [this.imports(), "class ".concat(generatedName, " {"), '    constructor () {', this.instances(indent8), this.forest(indent8), this.sheets(indent8), '    }', '}\n', "export default ".concat(generatedName, ";")].reduce(concat);
    }
  }]);

  return Es6Generator;
}();

function generate(model) {
  var generator = new Es6Generator(model);
  return generator.assemble();
}

module.exports = generate;

==> winnie-0.1.51.tgz: package/serial/model-to-code.js <==
'use strict';

var _toConsumableArray = require('@babel/runtime/helpers/toConsumableArray');
var _slicedToArray = require('@babel/runtime/helpers/slicedToArray');
var _classCallCheck = require('@babel/runtime/helpers/classCallCheck');
var _createClass = require('@babel/runtime/helpers/createClass');
var GridPane = require('kenga-containers/grid-pane');
var TabbedPane = require('kenga-containers/tabbed-pane');
var ColumnNode = require('kenga-grid/columns/column-node');
var Widget = require('kenga/widget');
require('./serials.js');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var _toConsumableArray__default = /*#__PURE__*/_interopDefaultLegacy(_toConsumableArray);
var _slicedToArray__default = /*#__PURE__*/_interopDefaultLegacy(_slicedToArray);
var _classCallCheck__default = /*#__PURE__*/_interopDefaultLegacy(_classCallCheck);
var _createClass__default = /*#__PURE__*/_interopDefaultLegacy(_createClass);
var GridPane__default = /*#__PURE__*/_interopDefaultLegacy(GridPane);
var TabbedPane__default = /*#__PURE__*/_interopDefaultLegacy(TabbedPane);
var ColumnNode__default = /*#__PURE__*/_interopDefaultLegacy(ColumnNode);
var Widget__default = /*#__PURE__*/_interopDefaultLegacy(Widget);

function concat(prev, item) {
  if (!!prev && !!item) return "".concat(prev, "\n").concat(item);else if (!!prev) return prev;else return item;
}

function decapitalize(name) {
  return name.substring(0, 1).toLowerCase() + name.substring(1);
}

function capitalize(name) {
  return name.split('-').map(function (item) {
    return item.substring(0, 1).toUpperCase() + item.substring(1);
  }).join('');
}

function lastSlashTail(name) {
  var lsi = name.lastIndexOf('/');

  if (lsi > -1) {
    return name.substring(lsi + 1, name.length);
  } else {
    return name;
  }
}

function nvl(placeholder, name) {
  return name ? name : placeholder;
}

var Es6Generator = /*#__PURE__*/function () {
  function Es6Generator(model) {
    _classCallCheck__default['default'](this, Es6Generator);

    this.model = model;
    this.consts = new Set();
    this.fromToLocalConstructor = new Map(); // item.from -> local constructor name

    this.widgetToConstName = new Map(); // widget name -> program 'const' name
  }

  _createClass__default['default'](Es6Generator, [{
    key: "generateConstName",
    value: function generateConstName(base) {
      var localConstName = base;
      var nameAttempt = 1;

      while (this.consts.has(localConstName)) {
        localConstName = "".concat(base).concat(nameAttempt++);
      }

      this.consts.add(localConstName);
      return localConstName;
    }
  }, {
    key: "constructorNameOf",
    value: function constructorNameOf(item) {
      if (this.fromToLocalConstructor.has(item.from)) {
        return this.fromToLocalConstructor.get(item.from);
      } else {
        var base = nvl('W', capitalize(lastSlashTail(item.from)).replace(/[^a-z0-9_]/gi, ''));
        var constructorLocalName = this.generateConstName(base);
        this.fromToLocalConstructor.set(item.from, constructorLocalName);
        return constructorLocalName;
      }
    }
  }, {
    key: "constNameOf",
    value: function constNameOf(widgetName) {
      if (this.widgetToConstName.has(widgetName)) {
        return this.widgetToConstName.get(widgetName);
      } else {
        var base = decapitalize(widgetName);
        var constName = this.generateConstName(base);
        this.widgetToConstName.set(widgetName, constName);
        return constName;
      }
    }
  }, {
    key: "imports",
    value: function imports() {
      var _this = this;

      var importsContent = Array.from(new Set(Array.from(this.model.widgets.values()).sort(function (item1, item2) {
        return item1.source.from < item2.source.from ? -1 : item1.source.from > item2.source.from ? 1 : 0;
      }).map(function (item) {
        return "import ".concat(_this.constructorNameOf(item.source), " from '").concat(item.source.from, "';");
      }))).reduce(concat);
      return !!importsContent ? "".concat(importsContent, "\n") : '';
    }
  }, {
    key: "instances",
    value: function instances(indent) {
      var _this2 = this;

      return Array.from(this.model.widgets.entries()).map(function (_ref) {
        var _ref2 = _slicedToArray__default['default'](_ref, 2),
            key = _ref2[0],
            item = _ref2[1];

        var widgetConstName = _this2.constNameOf(key);

        return [item.delegate instanceof GridPane__default['default'] ? "".concat(indent, "const ").concat(widgetConstName, " = new ").concat(_this2.constructorNameOf(item.source), "(").concat(item.delegate.rows, ", ").concat(item.delegate.columns, ");") : "".concat(indent, "const ").concat(widgetConstName, " = new ").concat(_this2.constructorNameOf(item.source), "();"), "".concat(indent, "this.").concat(widgetConstName, " = ").concat(widgetConstName, ";")].reduce(concat);
      }).reduce(concat, '');
    }
  }, {
    key: "forest",
    value: function forest(indent) {
      var _this3 = this;

      var queue = [];
      this.model.forest.forEach(function (item) {
        queue.push.apply(queue, _toConsumableArray__default['default'](item.children));
      });

      for (var i = 0; i < queue.length; i++) {
        queue.push.apply(queue, _toConsumableArray__default['default'](queue[i].children));
      }

      return queue.map(function (item) {
        return "".concat(indent).concat(_this3.constNameOf(item.parent.name), ".").concat(item.delegate instanceof ColumnNode__default['default'] ? 'addColumnNode' : 'add', "(").concat(_this3.constNameOf(item.name), ");");
      }).reduce(concat, '');
    }
  }, {
    key: "sheets",
    value: function sheets(indent) {
      var _this4 = this;

      return Array.from(this.model.widgets.entries()).map(function (_ref3) {
        var _ref4 = _slicedToArray__default['default'](_ref3, 2),
            key = _ref4[0],
            item = _ref4[1];

        var widgetConstName = _this4.constNameOf(key);

        var props = item.sheet.filter(function (p) {
          return p.edited && (!(item.delegate instanceof GridPane__default['default']) || p.name !== 'rows' && p.name !== 'columns') && (item.delegate.parent instanceof TabbedPane__default['default'] || !p.name.startsWith('tab.'));
        }).map(function (p) {
          var assignment = "".concat(indent, "    ").concat(widgetConstName, ".").concat(p.name, " = ").concat(typeof p.value === 'string' ? "'".concat(p.value, "'") : p.value && p.value.src && p.value.getAttribute ? "'".concat(p.value.getAttribute('src'), "'") : p.value, ";");

          if (item.delegate instanceof Widget__default['default'] && p.name === 'classes' && p.value) {
            assignment += "\n".concat(indent, "    ").concat(widgetConstName, ".element.className += ' ' + ").concat(widgetConstName, ".").concat(p.name, ";");
          }

          return assignment;
        }).reduce(concat, '');
        return !!props ? ["".concat(indent, "{"), props, "".concat(indent, "}")].reduce(concat) : '';
      }).reduce(concat, '');
    }
  }, {
    key: "assemble",
    value: function assemble() {
      var generatedName = 'KengaView';
      var indent8 = '        ';
      return [this.imports(), "class ".concat(generatedName, " {"), '    constructor () {', this.instances(indent8), this.forest(indent8), this.sheets(indent8), '    }', '}\n', "export default ".concat(generatedName, ";")].reduce(concat);
    }
  }]);

  return Es6Generator;
}();

function generate(model) {
  var generator = new Es6Generator(model);
  return generator.assemble();
}

module.exports = generate;
